==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IPBlockBuilder extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1.IPBlock,io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder>{
  public IPBlockBuilder() {
    this(false);
  }
  public IPBlockBuilder(java.lang.Boolean validationEnabled) {
    this(new IPBlock(), validationEnabled);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent) {
    this(fluent, false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IPBlock(), validationEnabled);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this(fluent, instance, false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCidr(instance.getCidr()); 
    fluent.withExcept(instance.getExcept()); 
    this.validationEnabled = validationEnabled; 
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this(instance,false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCidr(instance.getCidr()); 
    this.withExcept(instance.getExcept()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock build() {
    IPBlock buildable = new IPBlock(fluent.getCidr(),fluent.getExcept());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPBlockBuilder that = (IPBlockBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IPBlockBuilder extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1.IPBlock,io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder>{
  public IPBlockBuilder() {
    this(false);
  }
  public IPBlockBuilder(java.lang.Boolean validationEnabled) {
    this(new IPBlock(), validationEnabled);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent) {
    this(fluent, false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IPBlock(), validationEnabled);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this(fluent, instance, false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCidr(instance.getCidr()); 
    fluent.withExcept(instance.getExcept()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this(instance,false);
  }
  public IPBlockBuilder(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCidr(instance.getCidr()); 
    this.withExcept(instance.getExcept()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock build() {
    IPBlock buildable = new IPBlock(fluent.getCidr(),fluent.getExcept());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPBlockBuilder that = (IPBlockBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
